pub struct ClientAttTableBuilder { /* private fields */ }Expand description
A builder for ClientAttTable.
Entries must be pushed in ascending key order. Use build() to finalize.
Implementations
Sourceimpl ClientAttTableBuilder
impl ClientAttTableBuilder
Sourcepub fn push(&mut self, key: u16, value_len: u16, variable_len: bool)
pub fn push(&mut self, key: u16, value_len: u16, variable_len: bool)
Adds an entry with the given attribute handle and value size.
Panics
Panics if key is not greater than the previously pushed keys.
Sourcepub fn build(self) -> ClientAttTable
pub fn build(self) -> ClientAttTable
Consumes the builder and returns the completed ClientAttTable.